@@ -31,7 +31,7 @@ type App interface {
 	Changes() ([]Change, error)
 	LastChange() (Change, error)
 	BeginChange(ChangeMeta, int) (Change, error)
-	GCChanges(max int, reviewFunc func(changesToDelete []Change) error) (int, int, error)
+	GCChanges(maxValue int, reviewFunc func(changesToDelete []Change) error) (int, int, error)
 }
 
 type Change interface {
