@@ -4,7 +4,7 @@
 package app
 
 import (
-	ctlres "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/resources"
+	ctlres "carvel.dev/kapp/pkg/kapp/resources"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 )
 
