@@ -4,10 +4,10 @@
 package cmd
 
 import (
+	cmdcore "carvel.dev/kapp/pkg/kapp/cmd/core"
 	"github.com/cppforlife/go-cli-ui/ui"
 	uitable "github.com/cppforlife/go-cli-ui/ui/table"
 	"github.com/spf13/cobra"
-	cmdcore "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/cmd/core"
 )
 
 type UIFlags struct {
