@@ -1,11 +1,11 @@
-// Copyright 2021 VMware, Inc.
+// Copyright 2024 The Carvel Authors.
 // SPDX-License-Identifier: Apache-2.0
 
 package cmd
 
 import (
+	cmdcore "carvel.dev/kapp/pkg/kapp/cmd/core"
 	"github.com/spf13/cobra"
-	cmdcore "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/cmd/core"
 )
 
 type WarningFlags struct {
