@@ -67,12 +67,21 @@ rebaseRules:
   resourceMatchers:
   - apiVersionKindMatcher: {apiVersion: v1, kind: Namespace}
 
+# Kubernetes adds a label to namespaces
+- paths:
+  - [metadata, annotations, kubernetes.io/metadata.name]
+  type: copy
+  sources: [new, existing]
+  resourceMatchers:
+  - apiVersionKindMatcher: {apiVersion: v1, kind: Namespace}
+
 # PVC
 - paths:
   - [metadata, annotations, pv.kubernetes.io/bind-completed]
   - [metadata, annotations, pv.kubernetes.io/bound-by-controller]
   - [metadata, annotations, pv.kubernetes.io/migrated-to]
   - [metadata, annotations, volume.beta.kubernetes.io/storage-provisioner]
+  - [metadata, annotations, volume.kubernetes.io/storage-provisioner]
   - [spec, storageClassName]
   - [spec, volumeMode]
   - [spec, volumeName]
